==> haskell-xml-conduit-1.8.0.1-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.8.0.1
id: xml-conduit-1.8.0.1-6rjKJ2D4O7Y2I8MnTcGRXb
key: xml-conduit-1.8.0.1-6rjKJ2D4O7Y2I8MnTcGRXb
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
abi: d50c0b0b46d5ce41b4548f701f1181f7
exposed: True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
hidden-modules: Text.XML.Stream.Token
import-dirs: /usr/lib/ghc-8.6.4/site-local/xml-conduit-1.8.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/xml-conduit-1.8.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/xml-conduit-1.8.0.1
hs-libraries: HSxml-conduit-1.8.0.1-6rjKJ2D4O7Y2I8MnTcGRXb
depends:
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    conduit-1.3.1.1-FTcpSH31Ql3KtGJaaDZQpS
    conduit-extra-1.3.1.1-KcumXRXf8UFJSbEnt8yrMU containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 deepseq-1.4.4.0
    resourcet-1.2.2-5WRYEUs9Kel3m2rSVevxcM text-1.2.3.1
    transformers-0.5.6.2 xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.8.0.1-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.8.0.1
id: xml-conduit-1.8.0.1-6iTy1FflFjuHHVjd2Ii5zE
key: xml-conduit-1.8.0.1-6iTy1FflFjuHHVjd2Ii5zE
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
abi: 28662349b748aaba5a95f684757f768b
exposed: True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
hidden-modules: Text.XML.Stream.Token
import-dirs: /usr/lib/ghc-8.6.4/site-local/xml-conduit-1.8.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/xml-conduit-1.8.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/xml-conduit-1.8.0.1
hs-libraries: HSxml-conduit-1.8.0.1-6iTy1FflFjuHHVjd2Ii5zE
depends:
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    conduit-1.3.1.1-DBoWDvZgddMAQw9hEqn0dn
    conduit-extra-1.3.1.1-7ZxQ6ZiVjNd8QNBRTp16o containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 deepseq-1.4.4.0
    resourcet-1.2.2-1SMNkPIB95cIP5fLPJeWPc text-1.2.3.1
    transformers-0.5.6.2 xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
